@@ -50,7 +50,7 @@ fn main() {
         .build();
 
     let mut world = World::with_layout(&layout);
-    dispatcher.set_up(&mut world);
+    dispatcher.register_storages(&mut world);
 
     world.create_entity((Position(0, 0), Sprite { id: 0 }));
     world.create_entity((Position(1, 1), Sprite { id: 1 }));
