@@ -1,5 +1,6 @@
 pub use self::component::*;
 pub use self::component_set::*;
+pub use self::group_info::*;
 pub use self::storages::*;
 
 pub(crate) use self::grouping::*;
@@ -7,6 +8,7 @@ pub(crate) use self::masks::*;
 
 mod component;
 mod component_set;
+mod group_info;
 mod grouping;
 mod masks;
 mod storages;
