@@ -1,24 +1,16 @@
 use crate::components::Component;
 use crate::storage::ComponentStorage;
-use std::any;
 use std::any::TypeId;
 use std::cmp::{Eq, Ord, Ordering, PartialEq, PartialOrd};
 use std::hash::{Hash, Hasher};
 use std::marker::PhantomData;
+use std::{any, fmt};
 
 /// Holds information about a `Component` type.
 pub struct ComponentInfo {
     component: Box<dyn AbstractType>,
 }
 
-impl Clone for ComponentInfo {
-    fn clone(&self) -> Self {
-        Self {
-            component: self.component.clone(),
-        }
-    }
-}
-
 impl ComponentInfo {
     /// Creates a new `ComponentInfo` for the given `Component` type.
     pub fn new<T>() -> Self
@@ -46,6 +38,14 @@ impl ComponentInfo {
     }
 }
 
+impl Clone for ComponentInfo {
+    fn clone(&self) -> Self {
+        Self {
+            component: self.component.clone(),
+        }
+    }
+}
+
 impl PartialEq for ComponentInfo {
     fn eq(&self, other: &Self) -> bool {
         self.type_id().eq(&other.type_id())
@@ -75,6 +75,12 @@ impl Hash for ComponentInfo {
     }
 }
 
+impl fmt::Debug for ComponentInfo {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.write_str(self.component.type_name())
+    }
+}
+
 #[derive(Copy, Clone)]
 struct Type<T>(PhantomData<*const T>);
 
