@@ -1,6 +1,6 @@
-use crate::group::CombinedGroupInfo;
-use crate::query::{Passthrough, UnfilteredImmutableQueryElement};
-use crate::storage::{Entity, SparseArrayView};
+use crate::components::CombinedGroupInfo;
+use crate::query::{ImmutableUnfilteredQueryElement, Passthrough};
+use crate::storage::{Entity, EntitySparseArray};
 
 /// Trait implemented by the part of the `Query` that checks if an `Entity`
 /// includes or excludes a set of components.
@@ -60,20 +60,20 @@ unsafe impl<'a> QueryModifier<'a> for Passthrough {
 
 unsafe impl<'a, E> QueryModifier<'a> for E
 where
-    E: UnfilteredImmutableQueryElement<'a>,
+    E: ImmutableUnfilteredQueryElement<'a>,
 {
     const IS_PASSTHROUGH: bool = false;
 
-    type Split = SparseArrayView<'a>;
+    type Split = &'a EntitySparseArray;
 
     #[inline]
     fn includes(&self, entity: Entity) -> bool {
-        self.contains(entity)
+        self.contains(entity, &Passthrough)
     }
 
     #[inline]
     fn excludes(&self, entity: Entity) -> bool {
-        !self.contains(entity)
+        !self.contains(entity, &Passthrough)
     }
 
     fn group_info(&self) -> Option<CombinedGroupInfo<'a>> {
@@ -81,24 +81,24 @@ where
     }
 
     fn split_modifier(self) -> (Option<&'a [Entity]>, Self::Split) {
-        let (entities, sparse) = E::split(self).into_modifier_split();
+        let (entities, sparse, _, _) = E::split(self);
         (Some(entities), sparse)
     }
 
     #[inline]
     fn includes_split(split: &Self::Split, entity: Entity) -> bool {
-        split.contains(entity)
+        split.contains_entity(entity)
     }
 
     #[inline]
     fn excludes_split(split: &Self::Split, entity: Entity) -> bool {
-        !split.contains(entity)
+        !split.contains_entity(entity)
     }
 }
 
-macro_rules! sparse_array_view {
-    ($($elem:ident),+) => {
-        SparseArrayView<'a>
+macro_rules! entity_sparse_array {
+    ($elem:ident) => {
+        &'a EntitySparseArray
     };
 }
 
@@ -106,20 +106,20 @@ macro_rules! impl_query_modifier {
     ($(#[$attrib:meta];)* $(($elem:ident, $idx:tt)),+) => {
         unsafe impl<'a, $($elem),+> QueryModifier<'a> for ($($elem,)+)
         where
-            $($elem: UnfilteredImmutableQueryElement<'a>,)+
+            $($elem: ImmutableUnfilteredQueryElement<'a>,)+
         {
             const IS_PASSTHROUGH: bool = false;
 
-            type Split = ($(sparse_array_view!($elem),)+);
+            type Split = ($(entity_sparse_array!($elem),)+);
 
             $(#[$attrib])*
             fn includes(&self, entity: Entity) -> bool {
-                $(self.$idx.contains(entity))&&+
+                $(self.$idx.contains(entity, &Passthrough))&&+
             }
 
             $(#[$attrib])*
             fn excludes(&self, entity: Entity) -> bool {
-                $(!self.$idx.contains(entity))&&+
+                $(!self.$idx.contains(entity, &Passthrough))&&+
             }
 
             #[allow(clippy::needless_question_mark)]
@@ -128,17 +128,17 @@ macro_rules! impl_query_modifier {
             }
 
             fn split_modifier(self) -> (Option<&'a [Entity]>, Self::Split) {
-                split_modifier!($(($elem, self.$idx)),+)
+                split_modifier!($((self.$idx, $idx)),+)
             }
 
             $(#[$attrib])*
             fn includes_split(split: &Self::Split, entity: Entity) -> bool {
-                $(split.$idx.contains(entity))&&+
+                $(split.$idx.contains_entity(entity))&&+
             }
 
             $(#[$attrib])*
             fn excludes_split(split: &Self::Split, entity: Entity) -> bool {
-                $(!split.$idx.contains(entity))&&+
+                $(!split.$idx.contains_entity(entity))&&+
             }
         }
     };
