@@ -16,17 +16,20 @@ impl ResourceCell {
     }
 
     /// Returns a type-erased reference to the resource stored inside.
+    #[inline]
     pub fn value(&self) -> &dyn Resource {
         &*self.value
     }
 
+    #[inline]
     pub(crate) fn value_mut(&mut self) -> &mut dyn Resource {
         &mut *self.value
     }
 
     /// Returns the resource's `ChangeTicks`.
-    pub fn ticks(&self) -> ChangeTicks {
-        self.ticks
+    #[inline]
+    pub fn ticks(&self) -> &ChangeTicks {
+        &self.ticks
     }
 }
 
@@ -57,6 +60,10 @@ impl ResourceStorage {
             .map(|c| unsafe { *c.into_inner().value.downcast().unsafe_unwrap() })
     }
 
+    pub fn delete(&mut self, resource_type_id: &TypeId) -> bool {
+        self.resources.remove(resource_type_id).is_some()
+    }
+
     pub fn contains(&self, resource_type_id: &TypeId) -> bool {
         self.resources.contains_key(resource_type_id)
     }
