@@ -1,4 +1,4 @@
-use crate::storage::{Entity, IndexEntity, SparseArray, SparseArrayView};
+use crate::storage::{Entity, EntitySparseArray, IndexEntity};
 use crate::utils::ChangeTicks;
 use std::alloc::{alloc, dealloc, handle_alloc_error, realloc, Layout};
 use std::ptr::NonNull;
@@ -6,14 +6,14 @@ use std::{mem, ptr, slice};
 
 /// Type-erased storage for `Component`s.
 pub struct ComponentStorage {
-    layout: Layout,
-    sparse: SparseArray,
     entities: NonNull<Entity>,
+    len: usize,
+    sparse: EntitySparseArray,
     components: NonNull<u8>,
     ticks: NonNull<ChangeTicks>,
-    cap: usize,
-    len: usize,
+    layout: Layout,
     swap_space: NonNull<u8>,
+    cap: usize,
     drop: unsafe fn(*mut u8),
     needs_drop: bool,
 }
@@ -33,16 +33,14 @@ impl ComponentStorage {
             }
         };
 
-        let components = unsafe { NonNull::new_unchecked(layout.align() as _) };
-
         Self {
-            layout,
-            sparse: SparseArray::default(),
             entities: NonNull::dangling(),
-            components,
+            len: 0,
+            sparse: EntitySparseArray::default(),
+            components: NonNull::<T>::dangling().cast(),
             ticks: NonNull::dangling(),
             cap: 0,
-            len: 0,
+            layout,
             swap_space,
             drop: drop_in_place::<T>,
             needs_drop: mem::needs_drop::<T>(),
@@ -58,11 +56,11 @@ impl ComponentStorage {
     where
         T: 'static,
     {
-        let index_entity = self.sparse.get_mut_or_allocate_at(entity.index());
+        let index_entity = self.sparse.get_mut_or_allocate_at(entity.sparse());
 
         match index_entity {
             Some(index_entity) => {
-                let index = index_entity.index();
+                let index = index_entity.dense();
                 *self.entities.as_ptr().add(index) = entity;
                 *self.ticks.as_ptr().add(index) = ticks;
                 Some(
@@ -94,7 +92,7 @@ impl ComponentStorage {
     where
         T: 'static,
     {
-        let index = self.sparse.remove(entity)?;
+        let index = self.sparse.remove_entity(entity)?.dense();
 
         self.len -= 1;
 
@@ -103,7 +101,7 @@ impl ComponentStorage {
 
         if index < self.len {
             let index_entity = IndexEntity::new(index as u32, last_entity.version());
-            *self.sparse.get_unchecked_mut(last_entity.index()) = Some(index_entity);
+            *self.sparse.get_unchecked_mut(last_entity.sparse()) = Some(index_entity);
         }
 
         *self.ticks.as_ptr().add(index) = *self.ticks.as_ptr().add(self.len);
@@ -115,8 +113,8 @@ impl ComponentStorage {
     }
 
     pub(crate) fn remove_and_drop(&mut self, entity: Entity) {
-        let index = match self.sparse.remove(entity) {
-            Some(index) => index,
+        let index = match self.sparse.remove_entity(entity) {
+            Some(entity) => entity.dense(),
             None => return,
         };
 
@@ -128,7 +126,7 @@ impl ComponentStorage {
 
             if index < self.len {
                 let index_entity = IndexEntity::new(index as u32, last_entity.version());
-                *self.sparse.get_unchecked_mut(last_entity.index()) = Some(index_entity);
+                *self.sparse.get_unchecked_mut(last_entity.sparse()) = Some(index_entity);
             }
 
             let size = self.layout.size();
@@ -150,8 +148,8 @@ impl ComponentStorage {
         let entity_b = self.entities.as_ptr().add(b);
         ptr::swap(entity_a, entity_b);
 
-        let sparse_a = (*entity_a).index();
-        let sparse_b = (*entity_b).index();
+        let sparse_a = (*entity_a).sparse();
+        let sparse_b = (*entity_b).sparse();
         self.sparse.swap_unchecked(sparse_a, sparse_b);
 
         let size = self.layout.size();
@@ -166,105 +164,103 @@ impl ComponentStorage {
         ptr::swap(self.ticks.as_ptr().add(a), self.ticks.as_ptr().add(b));
     }
 
-    pub(crate) unsafe fn get<T>(&self, entity: Entity) -> Option<&T>
-    where
-        T: 'static,
-    {
-        let index = self.sparse.get_index(entity)?;
-        Some(&*self.components.cast::<T>().as_ptr().add(index))
+    #[inline]
+    pub(crate) unsafe fn get_unchecked<T>(&self, index: usize) -> &T {
+        &*self.components.cast::<T>().as_ptr().add(index)
     }
 
+    #[inline]
+    pub(crate) unsafe fn get_with_ticks_unchecked<T>(&self, index: usize) -> (&T, &ChangeTicks) {
+        (
+            &*self.components.cast::<T>().as_ptr().add(index),
+            &*self.ticks.as_ptr().add(index),
+        )
+    }
+
+    #[inline]
+    pub(crate) unsafe fn get_with_ticks_unchecked_mut<T>(
+        &mut self,
+        index: usize,
+    ) -> (&mut T, &mut ChangeTicks) {
+        (
+            &mut *self.components.cast::<T>().as_ptr().add(index),
+            &mut *self.ticks.as_ptr().add(index),
+        )
+    }
+    #[inline]
     pub(crate) fn get_ticks(&self, entity: Entity) -> Option<&ChangeTicks> {
-        let index = self.sparse.get_index(entity)?;
+        let index = self.sparse.get_entity(entity)?.dense();
         unsafe { Some(&*self.ticks.as_ptr().add(index)) }
     }
 
-    pub(crate) unsafe fn get_with_ticks<T>(&self, entity: Entity) -> Option<(&T, &ChangeTicks)>
-    where
-        T: 'static,
-    {
-        let index = self.sparse.get_index(entity)?;
-        Some((
-            &*self.components.cast::<T>().as_ptr().add(index),
-            &*self.ticks.as_ptr().add(index),
-        ))
+    #[inline]
+    pub(crate) unsafe fn get_with_ticks<T>(&self, entity: Entity) -> Option<(&T, &ChangeTicks)> {
+        let index = self.sparse.get_entity(entity)?.dense();
+        Some(self.get_with_ticks_unchecked(index))
     }
 
-    pub(crate) unsafe fn get_with_ticks_mut<T>(
-        &mut self,
-        entity: Entity,
-    ) -> Option<(&mut T, &mut ChangeTicks)>
-    where
-        T: 'static,
-    {
-        let index = self.sparse.get_index(entity)?;
-        Some((
-            &mut *self.components.cast::<T>().as_ptr().add(index),
-            &mut *self.ticks.as_ptr().add(index),
-        ))
-    }
-
-    pub(crate) fn get_index(&self, entity: Entity) -> Option<usize> {
-        self.sparse.get_index(entity)
+    #[inline]
+    pub(crate) fn get_index_entity(&self, entity: Entity) -> Option<&IndexEntity> {
+        self.sparse.get_entity(entity)
     }
 
+    #[inline]
     pub(crate) fn contains(&self, entity: Entity) -> bool {
-        self.sparse.contains(entity)
+        self.sparse.contains_entity(entity)
     }
 
+    #[inline]
     pub(crate) fn len(&self) -> usize {
         self.len
     }
 
+    #[inline]
     pub(crate) fn is_empty(&self) -> bool {
         self.len == 0
     }
 
-    pub(crate) fn capacity(&self) -> usize {
-        self.cap
-    }
-
+    #[inline]
     pub(crate) fn entities(&self) -> &[Entity] {
         unsafe { slice::from_raw_parts(self.entities.as_ptr(), self.len) }
     }
 
-    pub(crate) unsafe fn components<T>(&self) -> &[T]
-    where
-        T: 'static,
-    {
+    #[inline]
+    pub(crate) unsafe fn components<T>(&self) -> &[T] {
         slice::from_raw_parts(self.components.cast::<T>().as_ptr(), self.len)
     }
 
+    #[inline]
     pub(crate) fn ticks(&self) -> &[ChangeTicks] {
         unsafe { slice::from_raw_parts(self.ticks.as_ptr(), self.len) }
     }
 
-    pub(crate) fn split_for_iteration<T>(
+    pub(crate) fn split<T>(
         &self,
-    ) -> (SparseArrayView, &[Entity], *const T, *const ChangeTicks)
-    where
-        T: 'static,
-    {
+    ) -> (
+        &[Entity],
+        &EntitySparseArray,
+        NonNull<T>,
+        NonNull<ChangeTicks>,
+    ) {
         (
-            self.sparse.as_view(),
             unsafe { slice::from_raw_parts(self.entities.as_ptr(), self.len) },
-            self.components.cast::<T>().as_ptr(),
-            self.ticks.as_ptr(),
+            &self.sparse,
+            self.components.cast::<T>(),
+            self.ticks,
         )
     }
 
-    pub(crate) fn split_for_iteration_mut<T>(
-        &mut self,
-    ) -> (SparseArrayView, &[Entity], *mut T, *mut ChangeTicks)
+    pub(crate) unsafe fn iter<T>(&self) -> impl Iterator<Item = (&Entity, &T, &ChangeTicks)>
     where
         T: 'static,
     {
-        (
-            self.sparse.as_view(),
-            unsafe { slice::from_raw_parts(self.entities.as_ptr(), self.len) },
-            self.components.cast::<T>().as_ptr(),
-            self.ticks.as_ptr(),
-        )
+        self.entities().iter().enumerate().map(|(i, entity)| {
+            (
+                entity,
+                &*self.components.cast::<T>().as_ptr().add(i),
+                &*self.ticks.as_ptr().add(i),
+            )
+        })
     }
 
     pub(crate) fn clear(&mut self) {
