@@ -3,7 +3,7 @@ pub use self::dispatcher::*;
 pub use self::errors::*;
 pub use self::registry::*;
 pub use self::system::*;
-pub use self::system_parameter::*;
+pub use self::system_param::*;
 
 pub(crate) use self::command_buffers::*;
 
@@ -13,4 +13,4 @@ mod dispatcher;
 mod errors;
 mod registry;
 mod system;
-mod system_parameter;
+mod system_param;
