@@ -7,12 +7,24 @@ where
     Self: Iterator,
 {
     fn next_with_entity(&mut self) -> Option<(Entity, Self::Item)>;
+
+    fn fold_with_entity<B, F>(mut self, init: B, mut f: F) -> B
+    where
+        Self: Sized,
+        F: FnMut(B, (Entity, Self::Item)) -> B,
+    {
+        let mut accumulator = init;
+        while let Some(item) = self.next_with_entity() {
+            accumulator = f(accumulator, item);
+        }
+        accumulator
+    }
 }
 
 /// Trait used for creating an `EntityIter`.
 pub trait IntoEntityIterator
 where
-    Self: Iterator + Sized,
+    Self: EntityIterator + Sized,
 {
     /// Wrapps the iterator in an `EntityIter`.
     fn entities(self) -> EntityIter<Self>;
@@ -20,7 +32,7 @@ where
 
 impl<I> IntoEntityIterator for I
 where
-    I: Iterator + Sized,
+    I: EntityIterator + Sized,
 {
     fn entities(self) -> EntityIter<Self> {
         EntityIter(self)
@@ -37,7 +49,17 @@ where
 {
     type Item = (Entity, I::Item);
 
+    #[inline]
     fn next(&mut self) -> Option<Self::Item> {
         self.0.next_with_entity()
     }
+
+    #[inline]
+    fn fold<B, F>(self, init: B, f: F) -> B
+    where
+        Self: Sized,
+        F: FnMut(B, Self::Item) -> B,
+    {
+        self.0.fold_with_entity(init, f)
+    }
 }
